@@ -1,5 +1,5 @@
 from tempfile import mkdtemp
-import Image
+from PIL import Image
 
 
 class Thumbnailer(object):
